# ModelZoo

This is the ModelZoo created by the Analytics Club, IIT Madras

Models : 

* Computer Vision
  * Segmentation
    * 2D Segmentation
      * UNet 
      * UNet++
      * PSPNet
    * 3D Segmentation
      * PointNet
  * GAN
    * StackGAN
    * Inpainting

* Natural Language Processing
  * CharCNN
  * Adaptive Attention for Image Captioning

## Installation

Run the following to install:

**pip install modelzoo-iitm**

## Developing Model Zoo

To install modelzoo, along with the tools you need to develop and run tests, run the following in your virtualenv:

**pip install -e .[dev]**